==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/AzurePlatformStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AzurePlatformStatusFluent<A extends io.fabric8.openshift.api.model.AzurePlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCloudName();
  public A withCloudName(java.lang.String cloudName);
  public java.lang.Boolean hasCloudName();
  
  /**
   * Method is deprecated. use withCloudName instead.
   */
  @java.lang.Deprecated
  public A withNewCloudName(java.lang.String arg0);
  public java.lang.String getNetworkResourceGroupName();
  public A withNetworkResourceGroupName(java.lang.String networkResourceGroupName);
  public java.lang.Boolean hasNetworkResourceGroupName();
  
  /**
   * Method is deprecated. use withNetworkResourceGroupName instead.
   */
  @java.lang.Deprecated
  public A withNewNetworkResourceGroupName(java.lang.String arg0);
  public java.lang.String getResourceGroupName();
  public A withResourceGroupName(java.lang.String resourceGroupName);
  public java.lang.Boolean hasResourceGroupName();
  
  /**
   * Method is deprecated. use withResourceGroupName instead.
   */
  @java.lang.Deprecated
  public A withNewResourceGroupName(java.lang.String arg0);
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/AzurePlatformStatusFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface AzurePlatformStatusFluent<A extends io.fabric8.openshift.api.model.AzurePlatformStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getCloudName();
  public A withCloudName(java.lang.String cloudName);
  public java.lang.Boolean hasCloudName();
  
  /**
   * Method is deprecated. use withCloudName instead.
   */
  @java.lang.Deprecated
  public A withNewCloudName(java.lang.String arg0);
  public java.lang.String getNetworkResourceGroupName();
  public A withNetworkResourceGroupName(java.lang.String networkResourceGroupName);
  public java.lang.Boolean hasNetworkResourceGroupName();
  
  /**
   * Method is deprecated. use withNetworkResourceGroupName instead.
   */
  @java.lang.Deprecated
  public A withNewNetworkResourceGroupName(java.lang.String arg0);
  public java.lang.String getResourceGroupName();
  public A withResourceGroupName(java.lang.String resourceGroupName);
  public java.lang.Boolean hasResourceGroupName();
  
  /**
   * Method is deprecated. use withResourceGroupName instead.
   */
  @java.lang.Deprecated
  public A withNewResourceGroupName(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
